@@ -31,7 +31,8 @@ job.minute.during(5,50).every(5)
 job.hour.every(4)
 
 job.dow.on('SUN')
-job.month.during('APR', 'NOV')
+job.month.during('APR', 'JUN')
+job.month.also.during('OCT', 'DEC')
 
 job2 = cron.new(command='/foo/bar',comment='SomeID')
 job2.every_reboot()
@@ -76,10 +77,9 @@ import tempfile
 import subprocess as sp
 
 from datetime import datetime
-from cronlog import CronLog
 
 __pkgname__ = 'python-crontab'
-__version__ = '1.4.4'
+__version__ = '1.5'
 
 ITEMREX = re.compile('^\s*([^@#\s]+)\s+([^@#\s]+)\s+([^@#\s]+)' +
     '\s+([^@#\s]+)\s+([^@#\s]+)\s+([^#\n]*)(\s+#\s*([^\n]*)|$)')
@@ -119,7 +119,7 @@ S_INFO = [
 import platform
 py3 = platform.python_version()[0] == '3'
 WinOS = platform.system() == 'Windows'
-SunOS = not WinOS and (os.uname()[0] == "SunOS" or os.getenv('SunOS_TEST'))
+SystemV = not WinOS and (os.uname()[0] in ["SunOS","AIX","HP-UX"] or os.getenv('SystemV_TEST'))
 CRONCMD = "/usr/bin/crontab"
 if sys.argv[0].startswith('test_'):
     CRONCMD = './data/crontest'
@@ -167,6 +167,7 @@ class CronTab(object):
 
     @property
     def log(self):
+        from cronlog import CronLog
         if self._log == None or isinstance(self._log, basestring):
             self._log = CronLog(self._log, user=self.user or 'root')
         return self._log
@@ -387,7 +388,7 @@ class CronItem(object):
         """Render this set cron-job to a string"""
         time = self.render_time()
 
-        if self.special or time in SPECIALS.values():
+        if self.special or (time in SPECIALS.values() and not SystemV):
             if self.special:
                 time = self.special
             else:
@@ -567,21 +568,36 @@ class CronSlice(object):
     def __unicode__(self):
         return self.render()
 
-    def every(self, n_value):
+    def every(self, n_value, also=False):
         """Set the every X units value"""
-        self.parts = [ self.get_range( int(n_value) ) ]
-        return self.parts[0]
+        not also and self.clear()
+        self.parts.append( self.get_range( int(n_value) ) )
+        return self.parts[-1]
 
-    def on(self, *n_value):
-        """Set the on the time value."""
+    def on(self, *n_value, **opts):
+        """Set the time values to the specified placements."""
+        not opts.get('also', False) and self.clear()
         for av in n_value:
             self.parts += self._v(av),
+        return self.parts
 
-    def during(self, vfrom, vto):
+    def during(self, vfrom, vto, also=False):
         """Set the During value, which sets a range"""
+        not also and self.clear()
         self.parts.append(self.get_range(self._v(vfrom), self._v(vto)))
         return self.parts[-1]
 
+    @property
+    def also(self):
+        class Also(object):
+            def every(s, *a):
+                return self.every(*a, also=True)
+            def on(s, *a):
+                return self.on(*a, also=True)
+            def during(s, *a):
+                return self.during(*a, also=True)
+        return Also()
+
     def clear(self):
         """clear the slice ready for new vaues"""
         self.parts = []
@@ -692,7 +708,7 @@ class CronRange(object):
             value = _render_values([self.vfrom, self.vto], '-', resolve)
         if self.seq != 1:
             value += "/%d" % self.seq
-        if value != '*' and SunOS:
+        if value != '*' and SystemV:
             value = ','.join(map(str, range(self.vfrom, self.vto+1, self.seq)))
         return value
 
